@@ -9,6 +9,10 @@ import _flatten from "lodash/flatten";
 import _defaults from "lodash/defaults";
 import _assign from "lodash/assign";
 
+function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }
+
+function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
+
 function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }
 
 function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }
@@ -27,6 +31,7 @@ import Events from "./events";
 import Collection from "./collection";
 import Helpers from "./helpers";
 import Scale from "./scale";
+import Log from "./log";
 export default {
   getData: function (props, childComponents) {
     if (props.data) {
@@ -59,14 +64,14 @@ export default {
   getDomain: function (props, axis, childComponents) {
     childComponents = childComponents || React.Children.toArray(props.children);
     var propsDomain = Domain.getDomainFromProps(props, axis);
-    var minDomain = Domain.getMinFromProps(props, axis);
-    var maxDomain = Domain.getMaxFromProps(props, axis);
     var domainPadding = this.getDefaultDomainPadding(props, axis, childComponents);
     var domain;
 
     if (propsDomain) {
       domain = propsDomain;
     } else {
+      var minDomain = Domain.getMinFromProps(props, axis);
+      var maxDomain = Domain.getMaxFromProps(props, axis);
       var dataset = (props.data || props.y) && Data.getData(props);
       var dataDomain = dataset ? Domain.getDomainFromData(props, axis, dataset) : [];
       var childDomain = this.getDomainFromChildren(props, axis, childComponents);
@@ -232,6 +237,56 @@ export default {
     var max = childDomains.length === 0 ? 1 : Collection.getMaxValue(childDomains);
     return [min, max];
   },
+  addBinsToParentPropsIfHistogram: function (_ref) {
+    var children = _ref.children,
+        props = _ref.props,
+        childComponents = _ref.childComponents,
+        parentProps = _ref.parentProps;
+    var someChildrenAreHistograms = children.some(function (child) {
+      return child.type && child.type.role === "histogram";
+    });
+    var allChildrenAreHistograms = someChildrenAreHistograms && children.length && children.every(function (child) {
+      return child.type && child.type.role === "histogram";
+    });
+
+    if (someChildrenAreHistograms && !allChildrenAreHistograms) {
+      Log.warn("VictoryHistogram only supports being stacked with other VictoryHistogram components. Check to make sure that you are only passing VictoryHistogram components to VictoryStack");
+    } // if we are stacking histograms, we need to generate explicit bins
+    // or else each histogram may end up having different bins
+
+
+    if (!allChildrenAreHistograms) {
+      return parentProps;
+    }
+
+    var childBins = props.bins || childComponents[0].props.bins; // if we have explicit bins then we don't need to calculate them
+
+    if (!Array.isArray(childBins)) {
+      var combinedData = children.reduce(function (memo, child) {
+        var xAccessor = Helpers.createAccessor(child.props.x || "x");
+        return memo.concat(child.props.data.map(function (datum) {
+          return {
+            x: xAccessor(datum)
+          };
+        }));
+      }, []); // use the same function to generate bins as VictoryHistogram but with
+      // the combined data from above, then get explicit bins from that
+
+      var getFormattedHistogramData = children[0].type.getFormattedData;
+      childBins = getFormattedHistogramData({
+        data: combinedData,
+        bins: childBins
+      }).reduce(function (memo, _ref2, index) {
+        var x0 = _ref2.x0,
+            x1 = _ref2.x1;
+        return index === 0 ? memo.concat([x0, x1]) : memo.concat(x1);
+      }, []);
+    }
+
+    return _objectSpread({}, parentProps, {
+      bins: childBins
+    });
+  },
   getDataFromChildren: function (props, childComponents) {
     var polar = props.polar,
         startAngle = props.startAngle,
@@ -248,6 +303,13 @@ export default {
       maxDomain: maxDomain
     };
     var stack = 0;
+    var children = childComponents ? childComponents.slice(0) : React.Children.toArray(props.children);
+    parentProps = this.addBinsToParentPropsIfHistogram({
+      children: children,
+      props: props,
+      childComponents: childComponents,
+      parentProps: parentProps
+    });
 
     var iteratee = function (child, childName, parent) {
       var childProps = _assign({}, child.props, parentProps);
@@ -272,7 +334,6 @@ export default {
       });
     };
 
-    var children = childComponents ? childComponents.slice(0) : React.Children.toArray(props.children);
     var stacked = children.filter(function (c) {
       return c.type && c.type.role === "stack";
     }).length;
@@ -426,11 +487,11 @@ export default {
       y: _uniq(_flatten(_toConsumableArray(yStrings).concat(_toConsumableArray(dataStrings.y))))
     };
   },
-  getCategories: function (props) {
+  getCategories: function (props, childComponents, allStrings) {
     var xPropCategories = props.categories && !Array.isArray(props.categories) ? props.categories.x : props.categories;
     var yPropCategories = props.categories && !Array.isArray(props.categories) ? props.categories.y : props.categories;
     var fallbackRequired = !xPropCategories || !yPropCategories;
-    var fallbackProps = fallbackRequired ? this.getStringsFromChildren(props) : {};
+    var fallbackProps = fallbackRequired ? allStrings || this.getStringsFromChildren(props, childComponents) : {};
     var xCategories = xPropCategories || fallbackProps.x;
     var yCategories = yPropCategories || fallbackProps.y;
     return {
